@@ -26,8 +26,6 @@ test_that("n parameter works as expected", {
 })
 
 test_that("lawn_sample fails correctly", {
-  # missing arguments
-  expect_error(lawn_sample(), "NA is not defined")
   # n of negative number gives back no data
   expect_equal(length(lawn_sample(dat, -1)$features), 0)
   # n of character string errors
